Buginese unicode shaping
Functions
- is_
buginese - Check if a character is Buginese
- shape_
buginese - Shape/Reordering characters The shaping engine inserts a placeholder glyph (U+25CC) wherever combining marks occur without a valid base. The character U+25CC belongs to the class of generic bases (GB). Well-formed Buginese character clusters are defined as follows: